@@ -10,10 +10,10 @@
 *********************************************/
 #include <avr/io.h>
 #include <inttypes.h>
+#define F_CPU 1000000UL  // 1 MHz
+#include <avr/delay.h>
 
-//#define OLD 1
 
-#ifdef OLD
 /* compatibilty macros for old style */
 #ifndef cbi
 #define cbi(sfr, bit) (_SFR_BYTE(sfr) &= ~_BV(bit))
@@ -23,64 +23,54 @@
 #define sbi(sfr, bit) (_SFR_BYTE(sfr) |= _BV(bit))
 #endif
 
-#endif /*OLD*/
 
-void delay_ms(unsigned short ms)
+void delay_ms(unsigned int ms)
 /* delay for a minimum of <ms> */
-/* with a 1Mhz clock, the resolution is 1 ms */
 {
-	uint8_t inner,inner1;
-
-    	while (ms) {
-		inner = 100;
-		while (inner) {
-			inner--;
-			inner1 = 70;
-			while (inner1) {
-				inner1--;
-			}
-		}
+	// we use a calibrated macro. This is more
+	// accurate and not so much compiler dependent
+	// as self made code.
+	while(ms){
+		_delay_loop_2(240.0);
 		ms--;
 	}
 }
 
-#ifdef OLD
-// old style now depricated:
-void main(void)
-{
-	// enable  PC5 as output 
-	sbi(DDRC,PC5);
-	while (1) {
-		// led on, pin=0 
-		cbi(PORTC,PC5);
-		delay_ms(500);
-		// set output to 5V, LED off 
-		sbi(PORTC,PC5);
-		delay_ms(500);
-	}
-}
-
-#else
 
 /* new style */
-void main(void)
+int main(void)
 {
           /* INITIALIZE */
           /* enable PC5 as output */
-          DDRC|= _BV(PC5);
+          DDRC|= (1<<DDC5);
 
-
-          /* BLINK, BLINK ... */
-
-          /* PC5 is 5 (see file include/avr/iom8.h) and _BV(PC5) is 00100000 */
+          /* PC5 is 5 (see file include/avr/iom8.h) and 1<<PC5 is 00100000 
+	   * This can also be written as _BV(PC5)*/
           while (1) {
                       /* led on, pin=0 */
-                      PORTC &= ~_BV(PC5);
+                      PORTC &= ~(1<<PC5);
                       delay_ms(500);
                       /* set output to 5V, LED off */
-                      PORTC|= _BV(PC5);
+                      PORTC|= (1<<PC5);
                       delay_ms(500);
           }
+	  return(0);
 }
 
-#endif /*OLD*/
+
+// // old style now depricated:
+// int main(void)
+// {
+// 	// enable  PC5 as output 
+// 	sbi(DDRC,PC5);
+// 	while (1) {
+// 		// led on, pin=0 
+// 		cbi(PORTC,PC5);
+// 		delay_ms(500);
+// 		// set output to 5V, LED off 
+// 		sbi(PORTC,PC5);
+// 		delay_ms(500);
+// 	}
+// 	return(0);
+// }
+// // end of old style
